@@ -46,6 +46,8 @@ use App::Dochazka::CLI::Commands::Employee qw(
     set_employee_other_sec_id 
     set_employee_self_fullname
     set_employee_other_fullname 
+    set_employee_self_password
+    set_employee_other_password 
 );
 use App::Dochazka::CLI::Commands::History qw(
     add_priv_history
@@ -83,11 +85,11 @@ App::Dochazka::CLI::CommandMap - Command map
 
 =head1 VERSION
 
-Version 0.151
+Version 0.154
 
 =cut
 
-our $VERSION = '0.151';
+our $VERSION = '0.154';
 
 
 
@@ -528,10 +530,18 @@ my $dispatch_map = {
     "EMPLOYEE_SPEC" => \&employee_profile,
     "EMPLOYEE_SPEC PROFILE" => \&employee_profile,
     "EMPLOYEE_SPEC SHOW" => \&employee_profile,
+    "EMPLOYEE SEC_ID _TERM" => \&set_employee_self_sec_id,
     "EMPLOYEE SET SEC_ID _TERM" => \&set_employee_self_sec_id,
+    "EMPLOYEE FULLNAME" => \&set_employee_self_fullname,
     "EMPLOYEE SET FULLNAME" => \&set_employee_self_fullname,
+    "EMPLOYEE_SPEC SEC_ID _TERM" => \&set_employee_other_sec_id,
     "EMPLOYEE_SPEC SET SEC_ID _TERM" => \&set_employee_other_sec_id,
+    "EMPLOYEE_SPEC FULLNAME" => \&set_employee_other_fullname,
     "EMPLOYEE_SPEC SET FULLNAME" => \&set_employee_other_fullname,
+    "EMPLOYEE PASSWORD" => \&set_employee_self_password,
+    "EMPLOYEE SET PASSWORD" => \&set_employee_self_password,
+    "EMPLOYEE_SPEC PASSWORD" => \&set_employee_other_password,
+    "EMPLOYEE_SPEC SET PASSWORD" => \&set_employee_other_password,
 
     # Priv commands
     "PRIV" => \&show_current_priv,
@@ -553,6 +563,8 @@ my $dispatch_map = {
     "SCHEDULE SCODE _TERM" => \&assign_memsched_scode,
     "SCHEDULE_SPEC" => \&schedulespec,
     "SCHEDULE_SPEC SHOW" => \&schedulespec,
+    "SCHEDULE_SPEC REMARK" => \&schedulespec_remark,
+    "SCHEDULE_SPEC SCODE _TERM" => \&schedulespec_scode,
     "SCHEDULE_SPEC SET REMARK" => \&schedulespec_remark,
     "SCHEDULE_SPEC SET SCODE _TERM" => \&schedulespec_scode,
 
