@@ -57,11 +57,11 @@ App::Dochazka::CLI::Commands::Employee - Employee commands
 
 =head1 VERSION
 
-Version 0.151
+Version 0.154
 
 =cut
 
-our $VERSION = '0.151';
+our $VERSION = '0.154';
 
 
 
@@ -72,9 +72,11 @@ our $VERSION = '0.151';
 our @EXPORT_OK = qw( 
     employee_profile
     set_employee_self_sec_id 
-    set_employee_self_fullname 
     set_employee_other_sec_id
+    set_employee_self_fullname 
     set_employee_other_fullname
+    set_employee_self_password 
+    set_employee_other_password
 );
 
 
@@ -224,4 +226,58 @@ EOS
     return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $message );
 }
 
+
+=head2 set_employee_self_password
+
+Reset one's own password
+
+=cut
+
+sub set_employee_self_password {
+    return _set_password( $current_emp->eid ); 
+}
+
+
+=head2 set_employee_other_password
+
+Reset password of an arbitrary employee
+
+=cut
+
+sub set_employee_other_password {
+    print "Entering " . __PACKAGE__ . "::set_employee_other_password\n" if $debug_mode;
+    my ( $ts, $th ) = @_;
+
+    my $status = lookup_employee( $th->{EMPLOYEE_SPEC} );
+    return rest_error( $status, "Employee lookup" ) unless $status->ok;
+    my $emp_obj = App::Dochazka::REST::Model::Employee->spawn( %{ $status->payload } );
+
+    return _set_password( $emp_obj->eid );
+}
+
+
+# take EID parameter
+sub _set_password {
+    my $eid = shift;
+
+    # prompt for new password and take basic precautions
+    print "New password: ";
+    my $newpass = <>;
+    chomp( $newpass );
+    print "Again: ";
+    my $confirm = <>;
+    chomp( $confirm );
+    if ( $newpass ne $confirm ) {
+        return $CELL->status_err( 'DOCHAZKA_CLI_NO_MATCH' );
+    }
+
+    # send REST request
+    my $status = send_req( 'PUT', "employee/eid/$eid", <<"EOS" );
+{ "password" : "$newpass" }
+EOS
+
+    return $status;
+}
+
+
 1;
